==> haskell-persistent-test-2.0.3.0-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-test
version: 2.0.3.0
id: persistent-test-2.0.3.0-JaTnEhn51kVEmMV19kqzBI
key: persistent-test-2.0.3.0-JaTnEhn51kVEmMV19kqzBI
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.
category: Database, Yesod
abi: 8f46563cf276496f1760c2d269256f7e
exposed: True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest HtmlTest Init
    LargeNumberTest MaxLenTest MigrationColumnLengthTest
    MigrationIdempotencyTest MigrationOnlyTest MigrationTest
    MpsNoPrefixTest PersistTestPetCollarType PersistTestPetType
    PersistUniqueTest PersistentTest PersistentTestModels PrimaryTest
    RawSqlTest ReadWriteTest Recursive RenameTest SumTypeTest
    TransactionLevelTest TreeTest UniqueTest UpsertTest
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-test-2.0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-test-2.0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-test-2.0.3.0
hs-libraries: HSpersistent-test-2.0.3.0-JaTnEhn51kVEmMV19kqzBI
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    QuickCheck-2.13.2-KEVEjFnAQhp2P6vBjviJXi
    aeson-1.4.4.0-KwovUsQGNt8PPlzoq6sTW base-4.12.0.0
    blaze-html-0.9.1.1-Icge9VdFJKdIYmonGkJUKg bytestring-0.10.8.2
    conduit-1.3.1.1-A6bcVQctRolBYixAJR8St6 containers-0.6.0.1
    exceptions-0.10.2-F5iQJa9RoWHAiWKkKHwe3
    hspec-2.7.1-8yjc0CSgjCu2CF6Sl8z1Db
    hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
    monad-control-1.0.2.3-EKrTS47Oi8IKd1pTyskzd3
    monad-logger-0.3.30-A9f4lAC0Qx7HyjOf2bruBY
    path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    persistent-2.10.1-3WeJjc6nLHlBjEQ9ltg5fv
    persistent-template-2.7.2-eK7sNRNYLt69y3sbvA5aB
    quickcheck-instances-0.3.22-AYyObhB1mxNFiR8121oXeL
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-8hEDHRutAsl8XBsaHNUdIq text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-KWttVZ7nb0vsLFTQBq79t
    unliftio-0.2.12-1dOZyyjVQtI9lz6p9dfArS
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
haddock-interfaces: /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock
haddock-html: /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-test-2.0.3.0-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-test
version: 2.0.3.0
id: persistent-test-2.0.3.0-ACYdOdwt8Un5W5M0K7uQGG
key: persistent-test-2.0.3.0-ACYdOdwt8Un5W5M0K7uQGG
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.
category: Database, Yesod
abi: 5487428059898a5527d3d7ba26738b0a
exposed: True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest HtmlTest Init
    LargeNumberTest MaxLenTest MigrationColumnLengthTest
    MigrationIdempotencyTest MigrationOnlyTest MigrationTest
    MpsNoPrefixTest PersistTestPetCollarType PersistTestPetType
    PersistUniqueTest PersistentTest PersistentTestModels PrimaryTest
    RawSqlTest ReadWriteTest Recursive RenameTest SumTypeTest
    TransactionLevelTest TreeTest UniqueTest UpsertTest
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-test-2.0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-test-2.0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-test-2.0.3.0
hs-libraries: HSpersistent-test-2.0.3.0-ACYdOdwt8Un5W5M0K7uQGG
depends:
    HUnit-1.6.0.0-CIh8yVnXF8fEfjQqWNmj9c
    QuickCheck-2.13.2-2FrYL0Zx0JL1157x99MUYA
    aeson-1.4.4.0-2rVYFr4zHxOH3WhRjqDPZY base-4.12.0.0
    blaze-html-0.9.1.1-BVzzc2FJfx7GiAJyBgw5Ja bytestring-0.10.8.2
    conduit-1.3.1.1-DEyzgVREq8JGnMpn8fab1M containers-0.6.0.1
    exceptions-0.10.2-HDaOvlvHbPR767FjhdL1tt
    hspec-2.7.1-2ie8rFQemXtK3qtKDBhHSi
    hspec-expectations-0.8.2-9JgK0FgjaFj1ZSi2zSJcvx
    monad-control-1.0.2.3-8DH4P9dnphD9L0cGYZ8UHr
    monad-logger-0.3.30-GFNkND8cQVUKoPnWwj3wWG
    path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    persistent-2.10.1-CEmmdCsKjniE1tePq4P2bh
    persistent-template-2.7.2-2j7panoEIOL1cBkXnlP2Js
    quickcheck-instances-0.3.22-6fDuoT73Lx93kICL53ruCA
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-LNFC9oX9jZq9q4YtEcrXC text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-II2bOKw9mMZBRrynUnHtTn
    unliftio-0.2.12-1qTQajQfnO8A7kPjHIwpz
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-HXsxAsTvm9z649814xbQu4
haddock-interfaces: /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock
haddock-html: /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
